]> git.p6c8.net - jirafeau/pcanterino.git/commitdiff
#34 - change md5 to sha256
authorBlackeye <gitlab@blackeyeprojects.de>
Wed, 4 Feb 2026 00:33:51 +0000 (01:33 +0100)
committerBlackeye <gitlab@blackeyeprojects.de>
Wed, 4 Feb 2026 00:33:51 +0000 (01:33 +0100)
f.php
lib/functions.php

diff --git a/f.php b/f.php
index 269b10be94725f3395ec739c2e0a614767dbab80..92736f72e92133978c3b735f24b04812af5b6bf0 100644 (file)
--- a/f.php
+++ b/f.php
@@ -171,7 +171,7 @@ if (!empty($link['key'])) {
         require(JIRAFEAU_ROOT.'lib/template/footer.php');
         exit;
     } else {
-        if (hash_equals($link['key'], md5($_POST['key']))) {
+        if (hash_equals($link['key'], hash('sha256',$_POST['key']))) {
             $password_challenged = true;
         } else {
             sleep(2);
index 84bcea8ebaff44c805ac6a33d4b03c8abcd39c32..f55da7bf5415b018caeba8c7575e4a3f6abe1a14 100644 (file)
@@ -544,7 +544,7 @@ function jirafeau_add_file($file, $one_time_download, $key, $time, $ip, $crypt,
     /* hash password or empty. */
     $password = '';
     if (!empty($key)) {
-        $password = md5($key);
+        $password = hash('sha256',$key);
     }
 
     /* create link file */
@@ -1088,10 +1088,10 @@ function jirafeau_async_init($filename, $type, $one_time, $key, $time, $ip)
     $w_path = $p . $ref . '_data';
     touch($w_path);
 
/* md5 password or empty */
     $password = '';
     if (!empty($key)) {
-        $password = md5($key);
+        $password = hash('sha256',$key);
     }
 
     /* Store information. */
@@ -1379,7 +1379,7 @@ function jirafeau_decrypt_file_legacy($fp_src, $fp_dst, $k)
     $m = mcrypt_module_open('rijndael-256', '', 'ofb', '');
     /* Extract key and iv. */
     $crypt_key = $k;
-    $hash_key = md5($crypt_key);
+    $hash_key = hash('sha256',$crypt_key);
     $iv = jirafeau_crypt_create_iv($hash_key, mcrypt_enc_get_iv_size($m));
     /* Init module. */
     mcrypt_generic_init($m, $hash_key, $iv);
@@ -1642,7 +1642,7 @@ function jirafeau_escape($string)
 function jirafeau_admin_session_start()
 {
     $_SESSION['admin_auth'] = true;
-    $_SESSION['admin_csrf'] = md5(uniqid(mt_rand(), true));
+    $_SESSION['admin_csrf'] = hash('sha256',uniqid(mt_rand(), true));
 }
 
 function jirafeau_session_end()
@@ -1088,10 +1088,10 @@ function jirafeau_async_init($filename, $type, $one_time, $key, $time, $ip)
     touch($w_path);
 
-    /* md5 password or empty */
+    /* sha256 password or empty */
     $password = '';
     if (!empty($key)) {

patrick-canterino.de